==> zio-aws-iotanalytics_2.13-5.17.115.1-sources.jar: zio/aws/iotanalytics/model/CustomerManagedChannelS3Storage.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotanalytics.model.primitives.{RoleArn, S3KeyPrefix, BucketName}
import scala.jdk.CollectionConverters._
final case class CustomerManagedChannelS3Storage(
    bucket: BucketName,
    keyPrefix: Option[S3KeyPrefix] = None,
    roleArn: RoleArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage = {
    import CustomerManagedChannelS3Storage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        keyPrefix.map(value => S3KeyPrefix.unwrap(value): java.lang.String)
      )(_.keyPrefix)
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly =
    zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage
      .wrap(buildAwsValue())
}
object CustomerManagedChannelS3Storage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage =
      zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage(
        bucket,
        keyPrefix.map(value => value),
        roleArn
      )
    def bucket: BucketName
    def keyPrefix: Option[S3KeyPrefix]
    def roleArn: RoleArn
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getKeyPrefix: ZIO[Any, AwsError, S3KeyPrefix] =
      AwsError.unwrapOptionField("keyPrefix", keyPrefix)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ) extends zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly {
    override val bucket: BucketName =
      zio.aws.iotanalytics.model.primitives.BucketName(impl.bucket())
    override val keyPrefix: Option[S3KeyPrefix] = scala
      .Option(impl.keyPrefix())
      .map(value => zio.aws.iotanalytics.model.primitives.S3KeyPrefix(value))
    override val roleArn: RoleArn =
      zio.aws.iotanalytics.model.primitives.RoleArn(impl.roleArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ): zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotanalytics_2.13-7.21.15.2-sources.jar: zio/aws/iotanalytics/model/CustomerManagedChannelS3Storage.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.iotanalytics.model.primitives.{RoleArn, S3KeyPrefix, BucketName}
import scala.jdk.CollectionConverters._
final case class CustomerManagedChannelS3Storage(
    bucket: BucketName,
    keyPrefix: Optional[S3KeyPrefix] = Optional.Absent,
    roleArn: RoleArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage = {
    import CustomerManagedChannelS3Storage.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        keyPrefix.map(value => S3KeyPrefix.unwrap(value): java.lang.String)
      )(_.keyPrefix)
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly =
    zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage
      .wrap(buildAwsValue())
}
object CustomerManagedChannelS3Storage {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage =
      zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage(
        bucket,
        keyPrefix.map(value => value),
        roleArn
      )
    def bucket: BucketName
    def keyPrefix: Optional[S3KeyPrefix]
    def roleArn: RoleArn
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getKeyPrefix: ZIO[Any, AwsError, S3KeyPrefix] =
      AwsError.unwrapOptionField("keyPrefix", keyPrefix)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ) extends zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly {
    override val bucket: BucketName =
      zio.aws.iotanalytics.model.primitives.BucketName(impl.bucket())
    override val keyPrefix: Optional[S3KeyPrefix] = zio.aws.core.internal
      .optionalFromNullable(impl.keyPrefix())
      .map(value => zio.aws.iotanalytics.model.primitives.S3KeyPrefix(value))
    override val roleArn: RoleArn =
      zio.aws.iotanalytics.model.primitives.RoleArn(impl.roleArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.CustomerManagedChannelS3Storage
  ): zio.aws.iotanalytics.model.CustomerManagedChannelS3Storage.ReadOnly =
    new Wrapper(impl)
}
